Welcome to dicom_parser's documentation!
========================================

.. include:: overview.rst
.. include:: installation.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   vendors
   modules/modules
   release_notes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
